Graph
=====

.. currentmodule:: pqp.graph

.. autoclass:: Graph
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Graph.add_edge
      ~Graph.bi_edge_tuples
      ~Graph.di_edge_tuples
      ~Graph.draw
      ~Graph.idc

   .. rubric:: Methods Documentation

   .. automethod:: add_edge
   .. automethod:: bi_edge_tuples
   .. automethod:: di_edge_tuples
   .. automethod:: draw
   .. automethod:: idc
